package com.gyee.table.alarm;

import com.gyee.table.entity.ElectricalTestingPointDI;
import com.gyee.table.entity.ElectricalTestingPointDIEntity;
import com.gyee.table.service.ElectricalTestingPointDIDao;
import com.gyee.table.utils.DataUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Component;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Predicate;
import javax.persistence.criteria.Root;
import java.util.ArrayList;
import java.util.List;

@Component
public class JpaElectricalTestingPointDIDao implements ElectricalTestingPointDIDao {
    @Autowired
    private com.gyee.table.alarm.repository.ElectricalTestingPointDIRepository ElectricalTestingPointDIRepository;


    @Override
    public List<ElectricalTestingPointDI> findByUniformcodeNameWindpowerstationid(String uniformcode, String name, String windpowerstationid) {

        return findTest(uniformcode,name,windpowerstationid);
    }

    public List<ElectricalTestingPointDI> findTest(String uniformcode, String name, String windpowerstationid) {
        Specification querySpecifi = new Specification<ElectricalTestingPointDIEntity>() {
            @Override
            public Predicate toPredicate(Root<ElectricalTestingPointDIEntity> root, CriteriaQuery<?> criteriaQuery, CriteriaBuilder criteriaBuilder) {

                List<Predicate> predicates = new ArrayList<>();
                if (uniformcode != null && !uniformcode.trim().equals("")) {
                    predicates.add(criteriaBuilder.like(root.get("uniformCode"), "%" + uniformcode + "%" ));
                }
                if (name != null && !name.trim().equals("")) {
                    predicates.add(criteriaBuilder.like(root.get("name"),"%" + name + "%" ));
                }
                if (windpowerstationid != null && !windpowerstationid.trim().equals("")) {
                    predicates.add(criteriaBuilder.equal(root.get("windPowerStationId"), windpowerstationid));
                }
                return criteriaBuilder.and(predicates.toArray(new Predicate[predicates.size()]));
            }
        };

        List<ElectricalTestingPointDIEntity> all = ElectricalTestingPointDIRepository.findAll(querySpecifi);
        return DataUtil.convertDataList(all);
    }
}
