package com.gyee.table.controller;

import com.alibaba.fastjson2.JSONObject;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.gyee.table.entity.ComponentModificationRecord;
import com.gyee.table.entity.Configurationinfo;
import com.gyee.table.result.Result;
import com.gyee.table.service.IComponentModificationRecordService;
import com.gyee.table.service.IConfigurationinfoService;
import com.gyee.table.utils.SnowflakeIdUtils;
import com.gyee.table.utils.TableDataInfo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author hlf
 * @date 2023/3/20 10:03
 * 文件说明：
 */
@Slf4j
@RestController
@RequestMapping("/cic")
public class ComponentInformationController {

    @Resource
    private IConfigurationinfoService configurationinfoService;

    @Resource
    private IComponentModificationRecordService componentModificationRecordService;

    /**
     * 查询组件信息列表
     *
     * @return
     */
    @GetMapping("/componentList")
    public TableDataInfo componentList(@RequestBody Configurationinfo configurationinfo) {
        PageHelper.startPage(configurationinfo.getPageNum(), configurationinfo.getPageSize(), true);
        List<Configurationinfo> list = configurationinfoService.selectConfigurationinfoList(configurationinfo);
        return getDataTable(list);
    }

    /**
     * 新增组件信息
     *
     * @param configurationinfo
     * @return
     */
    @PostMapping("/addComponent")
    public JSONObject addComponent(@RequestBody Configurationinfo configurationinfo) {
        configurationinfo.setId(Long.toString(new SnowflakeIdUtils(1, 3).nextId()));
        configurationinfoService.save(configurationinfo);
        return Result.success();
    }

    /**
     * 修改组件信息
     *
     * @param configurationinfo
     * @return
     */
    @PostMapping("/updateComponent")
    public JSONObject updateComponent(@RequestBody Configurationinfo configurationinfo) {
        configurationinfoService.updateById(configurationinfo);
        ComponentModificationRecord componentModificationRecord = new ComponentModificationRecord();
        componentModificationRecord.setId(configurationinfo.getId());
        componentModificationRecord.setChangeUser(configurationinfo.getChangeUser());
        componentModificationRecord.setUpdataDate(configurationinfo.getUpdataDate());
        componentModificationRecordService.save(componentModificationRecord);
        return Result.success();
    }

    /**
     * 删除组件信息
     *
     * @param id
     * @return
     */
    @DeleteMapping("/deleteComponent/{id}")
    public JSONObject deleteComponent(@PathVariable String id) {
        configurationinfoService.removeById(id);
        return Result.success();
    }

    /**
     * 响应请求分页数据
     */
    @SuppressWarnings({ "rawtypes", "unchecked" })
    protected TableDataInfo getDataTable(List<?> list)
    {
        TableDataInfo rspData = new TableDataInfo();
        rspData.setCode(200);
        rspData.setRows(list);
        rspData.setTotal(new PageInfo(list).getTotal());
        rspData.setMsg("成功");
        return rspData;
    }
}
